Struct MemoryRegion
Source pub struct MemoryRegion { }
Information about a memory region.
Returns the address range of the memory region.
Returns the size of the memory region in bytes.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.